acnutils
========
.. image:: https://img.shields.io/github/workflow/status/AntiCompositeNumber/AntiCompositeBot/Python%20application
    :alt: GitHub Workflow Status
.. image:: https://coveralls.io/repos/github/AntiCompositeNumber/acnutils/badge.svg?branch=master
    :target: https://coveralls.io/github/AntiCompositeNumber/acnutils?branch=master
    :alt: Coverage status
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :alt: Code style: black
    :target: https://github.com/psf/black


A collection of various scripts used by AntiCompositeNumber's bots.

Feel free to use this if you find it useful, however, no guarentees of stability are made.
Pull requests are welcome, but may be declined if they would not be useful for my bots or tools.

Poetry is used for dependency management and package building.
